@@ -11,6 +11,7 @@ from tfx.types import artifact_utils
 from tfx.utils import io_utils
 from tfx.utils import path_utils
 # from tfx_bsl.tfxio import tf_example_record
+from tfx_bsl.tfxio import tf_example_record
 
 EXAMPLES_KEY = 'examples'
 OUTPUT_EXAMPLES_KEY = 'output_examples'
@@ -26,17 +27,17 @@ class Executor(base_executor.BaseExecutor):
     def Do(self, input_dict: Dict[Text, List[types.Artifact]],
            output_dict: Dict[Text, List[types.Artifact]],
            exec_properties: Dict[Text, Any]) -> None:
-        """Validate current model against last blessed model.
-    Args:
-      input_dict: Input dict from input key to a list of Artifacts.
-        - examples: Tensorflow Examples
-      output_dict: Output dict from output key to a list of Artifacts.
-        - output_examples: Tensorflow Examples
-      exec_properties: A dict of execution properties.
-        In this case there are no items in exec_properties, as stated by BaseComponentSpec
-    Returns:
-      None
-    """
+        """
+        Args:
+          input_dict: Input dict from input key to a list of Artifacts.
+            - examples: Tensorflow Examples
+          output_dict: Output dict from output key to a list of Artifacts.
+            - output_examples: Tensorflow Examples
+          exec_properties: A dict of execution properties.
+            In this case there are no items in exec_properties, as stated by BaseComponentSpec
+        Returns:
+          None
+        """
         self._log_startup(input_dict, output_dict, exec_properties)
 
         if EXAMPLES_KEY not in input_dict:
@@ -60,26 +61,27 @@ class Executor(base_executor.BaseExecutor):
             for split, uri in split_uris:
                 absl.logging.info('Loading examples for split {}'.format(split))
                 input_uri = io_utils.all_files_pattern(uri)
-                # input_tfxio = tf_example_record.TFExampleRecord(
-                #     file_pattern=input_uri,
-                #     telemetry_descriptors=_TELEMETRY_DESCRIPTORS
-                # )
+                input_tfxio = tf_example_record.TFExampleRecord(
+                    file_pattern=input_uri,
+                    telemetry_descriptors=_TELEMETRY_DESCRIPTORS
+                )
 
                 absl.logging.info(input_dict)
                 absl.logging.info(output_dict)
                 absl.logging.info('split: {}'.format(split))
                 absl.logging.info('uri: {}'.format(uri))
+                absl.logging.info('input_uri: {}'.format(input_uri))
 
                 # output_path = artifact_utils.get_split_uri(output_dict[OUTPUT_EXAMPLES_KEY],
                 #                                            split)
                 output_path = os.path.join(output_examples_artifacts[0].uri, split)
 
                 # loading the data and displaying
-                # data = pipeline | 'TFXIORead[{}]'.format(split) >> input_tfxio.BeamSource()
-                data = (pipeline
-                        | 'ReadExamplesFromTFRecord[{}]'.format(split) >> beam.io.ReadFromTFRecord(
-                            file_pattern=input_uri)
-                        | 'ParseExamples[{}]'.format(split) >> beam.Map(tf.train.Example.FromString))
+                data = pipeline | 'TFXIORead[{}]'.format(split) >> input_tfxio.BeamSource()
+                # data = (pipeline
+                #         | 'ReadExamplesFromTFRecord[{}]'.format(split) >> beam.io.ReadFromTFRecord(
+                #             file_pattern=input_uri)
+                #         | 'ParseExamples[{}]'.format(split) >> beam.Map(tf.train.Example.FromString))
 
                 # logging the rows, and writing them back to file
                 # this is of course not as efficient as copying the input files
