@@ -44,7 +44,7 @@ class SKLearnTransformSpec(ComponentSpec):
 
     PARAMETERS = {
         'module_file': ExecutionParameter(type=(str, Text)),
-        'pipeline_name': ExecutionParameter(type=(str, Text), optional=True),
+        'preprocessor_pipeline_name': ExecutionParameter(type=(str, Text), optional=True),
         # 'data_format': ExecutionParameter(type=(str, Text), optional=True),  # Default will be pandas
     }
     INPUTS = {
@@ -54,3 +54,4 @@ class SKLearnTransformSpec(ComponentSpec):
         'transformed_examples': ChannelParameter(type=standard_artifacts.Examples),
         'transform_pipeline': ChannelParameter(type=stfxe_artifacts.SKLearnPrepocessor)
     }
+
